/*
 * Copyright 2005 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/**
 * Copyright 2005 RAJD Consultancy Ltd. All rights reserved.
 */

package org.servicemix.jbi.messaging;

/**
 * AckHelper - helper class used by Delivery channel for monitoring process status *
 *
 * @version $Revision: 1.2 $
 */
class AckHelper {
    protected MessageExchangeImpl messageExchange;
    protected Object lock = new Object();
    protected boolean notified;

    /**
     * Construct a receipt holder
     * @param me
     */
    public AckHelper(MessageExchangeImpl me) {
        this.messageExchange = me;
    }
    
    /**
     * @return the MessageExchangeImpl
     */
    public MessageExchangeImpl getMessageExchange(){
        return messageExchange;
    }

    /**
     * Set the Receipt for this holder
     */
    public void done() {
        synchronized (lock) {
            notified = true;
            lock.notify();
        }
    }

    /**
     * @return true if acked
     */
    public boolean isAcked() {
        return isAcked(0);
    }

    /**
     * wait upto <Code>timeout</Code> timeout ms to get a receipt
     *
     * @param timeout
     * @return true if acked
     */
    public boolean isAcked(long timeout) {
        synchronized (lock) {
            if (!notified) {
                try {
                    lock.wait(timeout);
                }
                catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }
        }
        return notified;
    }
}
